@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-USER; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-who/packages.lisp,v 1.9 2005/08/02 18:17:41 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-who/packages.lisp,v 1.12 2006/10/10 07:38:02 edi Exp $
 
-;;; Copyright (c) 2003-2005, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2006, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -32,6 +32,7 @@
 #-:cormanlisp
 (defpackage #:cl-who
   (:use #:cl)
+  (:nicknames #:who)
   (:export #:*attribute-quote-char*
            #:*escape-char-p*
            #:*prologue*
@@ -42,6 +43,7 @@
            #:escape-string
            #:escape-string-all
            #:escape-string-iso-8859
+           #:escape-string-iso-8859-1
            #:escape-string-minimal
            #:escape-string-minimal-plus-quotes
            #:fmt
@@ -55,6 +57,7 @@
 #+:cormanlisp
 (defpackage "CL-WHO"
   (:use "CL")
+  (:nicknames "WHO")
   (:export "*ATTRIBUTE-QUOTE-CHAR*" 
            "*ESCAPE-CHAR-P*"
            "*PROLOGUE*"
@@ -63,6 +66,7 @@
            "ESCAPE-STRING"
            "ESCAPE-STRING-ALL"
            "ESCAPE-STRING-ISO-8859"
+           "ESCAPE-STRING-ISO-8859-1"
            "ESCAPE-STRING-MINIMAL"
            "ESCAPE-STRING-MINIMAL-PLUS-QUOTES"
            "FMT"
