@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package:CL-WHO; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-who/who.lisp,v 1.22 2005/08/02 18:17:41 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-who/who.lisp,v 1.27 2006/10/10 07:38:02 edi Exp $
 
-;;; Copyright (c) 2003-2005, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2006, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -92,7 +92,8 @@ indentation dynamically.")
 (defun escape-string (string &key (test *escape-char-p*))
   (declare (optimize speed))
   "Escape all characters in STRING which pass TEST. This function is
-not guaranteed to return a fresh string."
+not guaranteed to return a fresh string.  Note that you can pass NIL
+for STRING which'll just be returned."
   (let ((first-pos (position-if test string))
         (format-string (if (eq *html-mode* :xml) "&#x~x;" "&#~d;")))
     (if (not first-pos)
@@ -133,13 +134,18 @@ not guaranteed to return a fresh string."
   "Like ESCAPE-STRING-MINIMAL but also escapes quotes."
   (escape-string string :test #'(lambda (char) (find char "<>&'\""))))
 
-(defun escape-string-iso-8859 (string)
+(defun escape-string-iso-8859-1 (string)
   "Escapes all characters in STRING which aren't defined in
-ISO-8859. This of course assumes that STRING is an ISO-8859 string."
+ISO-8859-1."
   (escape-string string :test #'(lambda (char)
                                   (or (find char "<>&'\"")
                                       (> (char-code char) 255)))))
 
+(defun escape-string-iso-8859 (string)
+  "Identical to ESCAPE-STRING-8859-1.  Kept for backward
+compatibility."
+  (escape-string-iso-8859-1 string))
+
 (defun escape-string-all (string)
   "Escapes all characters in STRING which aren't in the 7-bit ASCII
 character set."
@@ -187,7 +193,7 @@ forms."
         for (attr . val) in attr-list
         unless (null val) ;; no attribute at all if VAL is NIL
           if (constantp val)
-            if (and (eq *html-mode* :sgml) (eq val t)) ; Special case for SGML
+            if (and (eq *html-mode* :sgml) (eq val t)) ; special case for SGML
               nconc (list " " (string-downcase attr))
             else
               nconc (list " "
@@ -204,8 +210,9 @@ forms."
                                  ;; VAL is T, use attribute's name
                                  (string-downcase attr))
                                 (t
-                                 ;; constant form, PRINC it
-                                 (format nil "~A" val)))
+                                 ;; constant form, PRINC it -
+                                 ;; EVAL is OK here because of CONSTANTP
+                                 (format nil "~A" (eval val))))
                           attribute-quote)
             end
           else
@@ -467,6 +474,7 @@ into Lisp code which creates the corresponding HTML as a string."
 ;; stuff for Nikodemus Siivola's HYPERDOC
 ;; see <http://common-lisp.net/project/hyperdoc/>
 ;; and <http://www.cliki.net/hyperdoc>
+;; also used by LW-ADD-ONS
 
 (defvar *hyperdoc-base-uri* "http://weitz.de/cl-who/")
 
